# mllearn
mllearn：machine learning in python

## Required

dependencies of mllearn:

- Python(>=3.8)
- NumPy(>=1.17.3)



## installation

```shell
pip install mlkit-lyt
```

or if you already have downloaded Numpy:

```shell
pip install -U mlkit-lyt
```



## Docs

TODO



## Testing 

TODO



## PR

TODO
